@@ -2,12 +2,9 @@ import random
 import aiosqlite
 import os
 
-from importlib_metadata import re
-
 from .utils import EmbedFactory
 from datetime import datetime
 from dotenv import load_dotenv
-from disnake import Embed
 from disnake.ext.commands import Cog, Context, Bot, CheckFailure, command
 
 
